package com.idsmanager.doraemondemoactivity.activity;

import android.Manifest;
import android.content.ClipData;
import android.content.ClipboardManager;
import android.content.Context;
import android.content.pm.PackageManager;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;

import com.alibaba.fastjson.JSONObject;
import com.esandinfo.etas.IfaaBaseInfo;
import com.idsmanager.doraemondemoactivity.DoraemonDemoApplication;
import com.idsmanager.doraemondemoactivity.R;
import com.idsmanager.doraemondemoactivity.callback.FetchAccessTokenCallBackImpl;
import com.idsmanager.doraemondemoactivity.config.DialogPortConfig;
import com.idsmanager.doraemondemoactivity.config.FullPortConfig;
import com.idsmanager.doraemonlibrary.DoraemonManager;
import com.idsmanager.doraemonlibrary.callback.DoraemonCallback;
import com.idsmanager.doraemonlibrary.config.BaseUIConfig;
import com.idsmanager.doraemonlibrary.dto.FetchAccessTokenRequest;
import com.idsmanager.doraemonlibrary.service.impl.DoraemonManagerServiceImpl;

import java.util.List;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    private String TAG = MainActivity.class.getSimpleName();

    EditText userid_text;
    EditText phone_number_text;
    TextView version_text;
    TextView fetch_access_token_request;
    TextView fetch_access_token_response;

    /**
     * 安全认证应用，点击复制秘钥
     */
    public static String appKey ;
    /**
     * 安全认证应用，应用详情中的 应用ID
     */
    public static String appId;
    /**
     * 需要根据文档开发后端接口获取
     * https://help.aliyun.com/zh/idaas/security-authentication/developer-reference/fetchaccesstoken?spm=a2c4g.11186623.0.i1
     */
    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        findViewById(R.id.init_btn).setOnClickListener(this);
        findViewById(R.id.phone_number_login_btn).setOnClickListener(this);
        findViewById(R.id.phone_number_verify_btn).setOnClickListener(this);
        findViewById(R.id.fingerprint_register_btn).setOnClickListener(this);
        findViewById(R.id.fingerprint_login_btn).setOnClickListener(this);
        findViewById(R.id.face_regist_btn).setOnClickListener(this);
        findViewById(R.id.face_login_btn).setOnClickListener(this);
        findViewById(R.id.get_support_biotypes).setOnClickListener(this);
        userid_text = findViewById(R.id.userid_text);
        phone_number_text = findViewById(R.id.phone_number_text);
        version_text = findViewById(R.id.version_text);
        version_text.setText(DoraemonManager.getVersion());
        checkPermission();
        initPageData();
    }

    private void initPageData() {
        FetchAccessTokenRequest fetchAccessTokenRequest = DoraemonManagerServiceImpl.getInstance(MainActivity.this.getApplicationContext()).getDoraemonService().getFetchAccessTokenRequest(MainActivity.appId, MainActivity.appId, userid_text.getText().toString(), MainActivity.appKey);
        fetch_access_token_request.setText(JSONObject.toJSONString(fetchAccessTokenRequest));
    }

    /**
     * 初始化SDK
     *
     * @param context 系统上下文
     * @param appId   应用ID
     */
    private void init(Context context, String appId) {
        DoraemonManager.init(context, appId, appKey, new FetchAccessTokenCallBackImpl(), new DoraemonCallback() {
            @Override
            public void onFailure(Exception e) {
                Log.e(TAG, "DoraemonManager init faild", e);
                MainActivity.this.showToast("SDK初始化失败！" + e.getMessage());
            }

            @Override
            public void onSuccess(Object data) {
                Log.e(TAG, "DoraemonManager init success");
                MainActivity.this.showToast("SDK初始化成功！");
            }
        });
    }


    /**
     * 本机手机号码一键登录
     */
    private void phoneNumberLogin() {
       BaseUIConfig baseUIConfig = new DialogPortConfig(this);
        // BaseUIConfig baseUIConfig = new FullPortConfig(this);
        DoraemonManager.phoneNumberLogin(this, new DoraemonCallback() {
            @Override
            public void onFailure(Exception e) {
                Log.e(TAG, "phoneNumberLogin faild", e);
                MainActivity.this.showToast("手机号登录失败！" + e.getMessage());
            }

            @Override
            public void onSuccess(Object data) {
                Log.e(TAG, "DoraemonManager init success");
                MainActivity.this.showToast("手机号码登录成功！" + data);
            }
        }, baseUIConfig);
    }

    /**
     * 手机号码验证
     *
     * @param phoneNum
     */
    private void phoneNumberVerify(String phoneNum) {
        DoraemonManager.phoneNumberVerify(phoneNum, new DoraemonCallback() {
            @Override
            public void onFailure(Exception e) {
                Log.e(TAG, "phoneNumberLogin faild", e);
                MainActivity.this.showToast("手机号认证失败！" + e.getMessage());
            }

            @Override
            public void onSuccess(Object data) {
                Log.e(TAG, "DoraemonManager init success");
                MainActivity.this.showToast("手机号码认证成功！" + data);
            }
        });
    }

    @Override
    public void onClick(View view) {
        String userID = userid_text.getText().toString();
        switch (view.getId()) {
            case R.id.init_btn:
                init(DoraemonDemoApplication.getContext(), appId);
                break;
            case R.id.phone_number_login_btn:
                phoneNumberLogin();
                break;
            case R.id.phone_number_verify_btn:
                String phoneNum = phone_number_text.getText().toString();
                phoneNumberVerify(phoneNum);
                break;
            case R.id.face_regist_btn:
                faceRegist(userID);
                break;
            case R.id.face_login_btn:
                faceLogin(userID);
                break;
            case R.id.fingerprint_register_btn:
                fingerRegist(userID);
                break;
            case R.id.fingerprint_login_btn:
                fingerLogin(userID);
                break;
            case R.id.get_support_biotypes:
                getSupportBIOTypes();
                break;
            case R.id.textview_copy:
                ClipboardManager clipboardManager = (ClipboardManager) getSystemService(Context.CLIPBOARD_SERVICE);
                String text = fetch_access_token_request.getText().toString();
                ClipData clipData = ClipData.newPlainText("text", text);
                clipboardManager.setPrimaryClip(clipData);
                Toast.makeText(this.getApplicationContext(), "已经复制到剪切板", Toast.LENGTH_SHORT).show();
                break;

        }

    }

    // 要申请的权限
    private String[] permissions = {Manifest.permission.CAMERA, Manifest.permission.INTERNET, Manifest.permission.ACCESS_NETWORK_STATE, Manifest.permission.CHANGE_WIFI_STATE};
    private static final int PERMISSION_REQUEST_CODE = 0;

    private boolean allRightGranted = false;

    private void checkPermission() {
        if (!allRightGranted) {
            // 版本判断。当手机系统大于 23 时，才有必要去判断权限是否获取
            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
                for (String permission : permissions) {
                    int premissionId = ContextCompat.checkSelfPermission(getApplicationContext(), permission);
                    if (premissionId != PackageManager.PERMISSION_GRANTED) {
                        ActivityCompat.requestPermissions(this, permissions, PERMISSION_REQUEST_CODE);
                    }
                }
            }
        }
    }

    @Override
    public void onRequestPermissionsResult(int requestCode, @NonNull String[] permissions, @NonNull int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        if (requestCode == PERMISSION_REQUEST_CODE) {
            boolean allgranted = true;
            for (int i : grantResults) {
                if (i != 0) {
                    allgranted = false;
                }
            }
            allRightGranted = allgranted;
        }
    }


    /**
     * 指纹注册
     */
    private void fingerRegist(String userID) {
        DoraemonManager.ifaaRegist(IfaaBaseInfo.IFAAAuthTypeEnum.AUTHTYPE_FINGERPRINT, userID, new DoraemonCallback() {
            @Override
            public void onFailure(Exception e) {
                Log.e(TAG, "Finger regist faild", e);
                MainActivity.this.showToast("指纹注册失败！" + e.getMessage());
            }

            @Override
            public void onSuccess(Object data) {
                Log.e(TAG, "Finger regist success");
                MainActivity.this.showToast("指纹注册成功！" + data);
            }
        });

    }

    /**
     * 指纹登录
     *
     * @param userID
     */
    private void fingerLogin(String userID) {
        DoraemonManager.ifaaLogin(IfaaBaseInfo.IFAAAuthTypeEnum.AUTHTYPE_FINGERPRINT, userID, new DoraemonCallback() {
            @Override
            public void onFailure(Exception e) {
                Log.e(TAG, "Finger login faild", e);
                MainActivity.this.showToast("指纹登录失败！" + e.getMessage());
            }

            @Override
            public void onSuccess(Object data) {
                Log.e(TAG, "Finger login success");
                MainActivity.this.showToast("指纹登录成功！" + data);
            }
        });

    }


    /**
     * 注册人脸
     */
    private void faceRegist(String userID) {
        checkPermission();
        DoraemonManager.ifaaRegist(IfaaBaseInfo.IFAAAuthTypeEnum.AUTHTYPE_FACE, userID, new DoraemonCallback() {
            @Override
            public void onFailure(Exception e) {
                Log.e(TAG, "Face regist faild", e);
                MainActivity.this.showToast("人脸注册失败！" + e.getMessage());
            }

            @Override
            public void onSuccess(Object data) {
                Log.e(TAG, "Face regist success");
                MainActivity.this.showToast("人脸注册成功！" + data);
            }
        });

    }

    /**
     * 人脸登录
     *
     * @param userID
     */
    private void faceLogin(String userID) {
        DoraemonManager.ifaaLogin(IfaaBaseInfo.IFAAAuthTypeEnum.AUTHTYPE_FACE, userID, new DoraemonCallback() {
            @Override
            public void onFailure(Exception e) {
                Log.e(TAG, "Face login faild", e);
                MainActivity.this.showToast("人脸登录失败！" + e.getMessage());
            }

            @Override
            public void onSuccess(Object data) {
                Log.e(TAG, "Face login success");
                MainActivity.this.showToast("人脸登录成功！" + data);
            }
        });

    }

    /**
     * 获取支持的生物识别
     */
    private void getSupportBIOTypes() {
        List<IfaaBaseInfo.IFAAAuthTypeEnum> supportBIOTypes = DoraemonManager.getSupportBIOTypes(MainActivity.this);
        StringBuffer sb = new StringBuffer();
        for (IfaaBaseInfo.IFAAAuthTypeEnum supportBIOType : supportBIOTypes) {
            sb.append(supportBIOType.getName()).append(",");
        }
        showToast("本机支持：" + sb);
    }

    private void showToast(String message) {
        runOnUiThread(() -> Toast.makeText(MainActivity.this, message, Toast.LENGTH_LONG).show());
    }


}